## Course Crawler

一个基于 Python 3 的 MOOC 课程下载工具，可以获取 [中国大学MOOC](https://www.icourse163.org/)、[学堂在线](http://www.xuetangx.com/)、[网易云课堂 MOOC](http://mooc.study.163.com/)、[好大学在线](https://www.cnmooc.org/)、[爱课程](http://www.icourses.cn/) 的课件，方便离线观看。

详细信息和用法请见 [https://mooc.xoy.io/](https://mooc.xoy.io/)。

### 声明

仅限个人学习和研究使用，切勿用于其他用途。强烈建议到 MOOC 网站进行学习，本程序只是提供一个备选方案。

本程序主体功能只是下载课件和附件，无任何手段获得付费课程，也没有以任何方式向任何人收取费用。

如果将程序用于商业用途或其他非法用途，一切后果由用户自负。

如果您发现有侵犯到您的合法权益，请与我联系删除相关代码，同时我对无意冒犯到您致以深深的歉意。

### 许可协议

请遵照 MIT 许可使用该程序。
